@@ -7,29 +7,28 @@
 
 
 #include "cuhre_util.h"
+
 /* Compilation note for R interface: add inclR.h */
 #include "inclR.h"
 
-/*  Compilation note for R interface:
- modif #define Print(s) puts(s); fflush(stdout) */
-#define Print(s) Rprintf(s)
+extern bool cuhreBadDimension(ccount ndim);
+extern bool cuhreBadComponent(cint ncomp);
+extern int cuhreIntegrate(  ctreal epsrel, ctreal epsabs,
+  cint flags, number mineval, cnumber maxeval, ccount key,
+			    real *integral, real *erreur, real *prob);
 
 
-static Integrand integrand_;
-
 /*********************************************************************/
 /* La fonction R  intgrer et son environnement d'execution */
 /*********************************************************************/
-SEXP rho, f;		
-/* Compilation note for R interface:  global, to be used by Sample*/
-real *lower_, *upper_,  prdbounds_;
+SEXP rho, globf;		
 
 /*********************************************************************/
 /* The function RIntegrand calls the R user function */
 /*********************************************************************/
-static void RIntegrand(ccount *ndim, creal xx[],
+static void RIntegrand(ccount *ndim, ctreal xx[],
 		       ccount  *ncomp,
-		       creal *lower, creal *upper, creal prdbounds, 
+		       ctreal *lower, ctreal *upper, ctreal prdbounds, 
 		       real ff[])
 {
   SEXP args, callsxp,resultsxp;
@@ -44,7 +43,7 @@ static void RIntegrand(ccount *ndim, creal xx[],
     REAL(args)[i] = xx[i] * (upper_[i] - lower_[i]) + lower_[i];
 
   /* Call the R function */
-  PROTECT(callsxp=lang2( f, args));
+  PROTECT(callsxp=lang2( globf, args));
   // PROTECT(args=eval(callsxp,rho));
  PROTECT(resultsxp=eval(callsxp,rho));
  UNPROTECT(4);
@@ -56,41 +55,29 @@ if  (length(resultsxp) != *ncomp)
  }
 } // End RIntegrand
 
-/*********************************************************************/
-
-static inline void DoSample(count n, creal *x,  real *f)
-{
-  neval_ += n;
-  while( n-- ) {
-    integrand_(&ndim_, x, &ncomp_,  lower_, upper_, prdbounds_, f);
-    x += ndim_;
-    f += ncomp_;
-  }
-}
 
 /*********************************************************************/
 
-#include "cuhre_common.h"
 
-Extern void EXPORT(Cuhre)(ccount ndim, ccount ncomp,
+ void EXPORT(Cuhre)(ccount ndim, ccount ncomp,
   Integrand integrand,
-  creal epsrel, creal epsabs,
+  ctreal epsrel, ctreal epsabs,
   cint flags, cnumber mineval, cnumber maxeval,
   ccount key,
   count *pnregions, number *pneval, int *pfail,
-  real *integral, real *error, real *prob)
+  real *integral, real *erreur, real *prob)
 {
   ndim_ = ndim;
   ncomp_ = ncomp;
 
-  if( BadComponent(ncomp) || BadDimension(ndim) ) *pfail = -1;
+  if( cuhreBadComponent(ncomp) || cuhreBadDimension(ndim) ) *pfail = -1;
   else {
     neval_ = 0;
     integrand_ = integrand;
 
-    *pfail = Integrate( epsrel, Max(epsabs, NOTZERO),
+    *pfail = cuhreIntegrate( epsrel, Max(epsabs, NOTZERO),
       flags, mineval, maxeval, key,
-      integral, error, prob);
+      integral, erreur, prob);
 
     *pnregions = nregions_;
     *pneval = neval_;
@@ -101,11 +88,11 @@ Extern void EXPORT(Cuhre)(ccount ndim, ccount ncomp,
 
 void (cuhre)(ccount *pndim, ccount *pncomp,
   Integrand integrand,
-  creal *pepsrel, creal *pepsabs,
+  ctreal *pepsrel, ctreal *pepsabs,
   cint *pflags, cnumber *pmineval, cnumber *pmaxeval,
   ccount *pkey,
   count *pnregions, number *pneval, int *pfail,
-  real *integral, real *error, real *prob)
+  real *integral, real *erreur, real *prob)
 {
 
   EXPORT(Cuhre)(*pndim, *pncomp, integrand,
@@ -113,7 +100,7 @@ void (cuhre)(ccount *pndim, ccount *pncomp,
     *pflags, *pmineval, *pmaxeval,
     *pkey,
     pnregions, pneval, pfail,
-    integral, error, prob);
+    integral, erreur, prob);
 }
 
 /*********************************************************************/
@@ -129,30 +116,30 @@ void Rcuhre(int *pndim, int *pncomp,
   int *pmersenneseed, int *pflags, int *pmineval, int *pmaxeval,
 	    int *key, 
   int *pnregions, int *pneval, int *pfail,
-  double *integral, double *error, double *prob)
+  double *integral, double *erreur, double *prob)
 {
-extern unsigned int mersenneseed;
 
   /* store the R function and its environment  in a  global*/
   rho= (SEXP)(env);
-  f= (SEXP)(integrand);
+  globf= (SEXP)(integrand);
   lower_ = lower;
   upper_ = upper;
   prdbounds_ = *prdbounds;
-  /* mersenneseed is ignored in cuhre */
+  /* mersenneseed is ignored in cuhre
 
   if (NA_INTEGER != *pmersenneseed) 
     SUFFIX(mersenneseed)= *pmersenneseed;
+ */
 
  /* call cuhre */
 
   cuhre((ccount *)pndim, (ccount *)pncomp,
 	(Integrand)RIntegrand,
- (creal *)pepsrel, (creal *)pepsabs,
+ (ctreal *)pepsrel, (ctreal *)pepsabs,
 	(cint *)pflags, (cnumber *)pmineval, (cnumber *)pmaxeval,
 	(ccount *)key,
 	(count *) pnregions,
 	(number *)pneval, (int *)pfail,
-	(real *)integral, (real *)error, (real *)prob);
+	(real *)integral, (real *)erreur, (real *)prob);
 
 } // End Rcuhre
