@@ -6,29 +6,33 @@
 */
 
 
+#include "common_stddecl.h"
+#include "struct_Random.h"
 #include "suave_util.h"
-/* Compilation note for R interface: add inclR.h  */
 #include "inclR.h"
+extern bool suaveBadDimension(cint ndim, cint flags);
+extern bool suaveBadComponent(cint ncomp);
+extern  int suaveIntegrate(  ctreal epsrel, ctreal epsabs,
+  cint flags, cnumber mineval, cnumber maxeval,
+  cnumber nnew, ctreal flatness,
+		      real *integral, real *erreur, real *prob);
 
 /* Compilation note for R interface: modif #define Print(s) puts(s); fflush(stdout) */
 #define Print(s) Rprintf(s)
 
-static Integrand integrand_;
 /*********************************************************************/
 /* Compilation note for R interface: 
    The integration R function and its execution environnement */
 /*********************************************************************/
-SEXP rho, f;		
-/*Compilation note for R interface: global, to be used by Sample */
-real *lower_, *upper_,  prdbounds_;
+SEXP rho, globf;		
 
 /*********************************************************************/
 /*The function RIntegrand calls the R user function */
 /*********************************************************************/
-static void RIntegrand(ccount *ndim, creal xx[],
+static void RIntegrand(ccount *ndim, ctreal xx[],
                       ccount *ncomp, 
-       creal *lower, creal *upper, creal prdbounds, real ff[],
-		       creal *weight)
+       ctreal *lower, ctreal *upper, ctreal prdbounds, real ff[],
+		       ctreal *weight)
 {
    SEXP args, argw, s, t, resultsxp;
   int i;
@@ -47,7 +51,7 @@ PROTECT(argw=allocVector(REALSXP, (1 )));
   /* Appel de la fonction R */
  PROTECT(t = s = allocList(3));
          SET_TYPEOF(s, LANGSXP);
-         SETCAR(t, f); t = CDR(t);
+         SETCAR(t, globf); t = CDR(t);
          SETCAR(t,  args); t = CDR(t);
          SETCAR(t, argw);
 
@@ -62,41 +66,29 @@ if  (length(resultsxp) != *ncomp)
  }
 } // End RIntegrand
 
-/*********************************************************************/
-
-static inline void DoSample(number n, creal *w, creal *x, real *f)
-{
-  neval_ += n;
-  while( n-- ) {
-    integrand_(&ndim_, x, &ncomp_, lower_, upper_, prdbounds_, f, w++);
-    x += ndim_;
-    f += ncomp_;
-  }
-}
 
 /*********************************************************************/
 
-#include "suave_common.h"
 
-Extern void EXPORT(Suave)(ccount ndim, ccount ncomp,
+ void EXPORT(Suave)(ccount ndim, ccount ncomp,
   Integrand integrand,
-  creal epsrel, creal epsabs,
+  ctreal epsrel, ctreal epsabs,
   cint flags, cnumber mineval, cnumber maxeval,
-  cnumber nnew, creal flatness,
+  cnumber nnew, ctreal flatness,
   count *pnregions, number *pneval, int *pfail,
-  real *integral, real *error, real *prob)
+  real *integral, real *erreur, real *prob)
 {
   ndim_ = ndim;
   ncomp_ = ncomp;
 
-  if( BadComponent(ncomp) || BadDimension(ndim, flags) ) *pfail = -1;
+  if( suaveBadComponent(ncomp) || suaveBadDimension(ndim, flags) ) *pfail = -1;
   else {
     neval_ = 0;
     integrand_ = integrand;
 
-    *pfail = Integrate( epsrel, Max(epsabs, NOTZERO),
+    *pfail = suaveIntegrate( epsrel, Max(epsabs, NOTZERO),
       flags, mineval, maxeval, nnew, flatness,
-      integral, error, prob);
+      integral, erreur, prob);
     *pnregions = nregions_;
     *pneval = neval_;
   }
@@ -106,11 +98,11 @@ Extern void EXPORT(Suave)(ccount ndim, ccount ncomp,
 
 void (suave)(ccount *pndim, ccount *pncomp,
   Integrand integrand,
-  creal *pepsrel, creal *pepsabs,
+  ctreal *pepsrel, ctreal *pepsabs,
   cint *pflags, cnumber *pmineval, cnumber *pmaxeval,
-  cnumber *pnnew, creal *pflatness,
+  cnumber *pnnew, ctreal *pflatness,
   count *pnregions, number *pneval, int *pfail,
-  real *integral, real *error, real *prob)
+  real *integral, real *erreur, real *prob)
 {
   EXPORT(Suave)(*pndim, *pncomp,
     integrand,
@@ -118,7 +110,7 @@ void (suave)(ccount *pndim, ccount *pncomp,
     *pflags, *pmineval, *pmaxeval,
     *pnnew, *pflatness,
     pnregions, pneval, pfail,
-    integral, error, prob);
+    integral, erreur, prob);
 }
 
 /*********************************************************************/
@@ -133,11 +125,11 @@ void Rsuave(int *pndim, int *pncomp,
    int *pmersenneseed, int *pflags, int *pmineval, int *pmaxeval,
   int *pnnew, double *pflatness, 
   int *pnregions, int *pneval, int *pfail,
-  double *integral, double *error, double *prob)
+  double *integral, double *erreur, double *prob)
 {
   /* store the R function and its environment  dans un global*/
   rho= (SEXP)(env);
-  f= (SEXP)(integrand);
+  globf= (SEXP)(integrand);
   lower_ = lower;
   upper_ = upper;
   prdbounds_ = *prdbounds;
@@ -146,14 +138,13 @@ void Rsuave(int *pndim, int *pncomp,
      SUFFIX(mersenneseed)= *pmersenneseed;
 
  /* call suave */
-
   suave((ccount *)pndim, (ccount *)pncomp,
 	(Integrand)RIntegrand,
-  (creal *)pepsrel, (creal *)pepsabs,
+  (ctreal *)pepsrel, (ctreal *)pepsabs,
 	(cint *)pflags, (cnumber *)pmineval, (cnumber *)pmaxeval,
-  (cnumber *)pnnew, (creal *)pflatness, 
+  (cnumber *)pnnew, (ctreal *)pflatness, 
 	(count *) pnregions,
 	(number *)pneval, (int *)pfail,
-	(real *)integral, (real *)error, (real *)prob);
+	(real *)integral, (real *)erreur, (real *)prob);
 
 } // End Rsuave
